@@ -1,18 +1,14 @@
 # Copyright (c) 2007-2009 David Caldwell,  All Rights Reserved. -*- perl -*-
 
 package Darcs::Inventory::Diff; use warnings; use strict;
-use Exporter 'import'; our @EXPORT = qw(darcs_inventory_diff);
+our @EXPORT = qw(darcs_inventory_diff);
 
 *darcs_inventory_diff = \&diff;
 
 sub hashify($) {
     my $order = 0;
     return () unless defined $_[0];
-    map {
-        my $diffable = $_->raw;
-        $diffable =~ s/^hash:.*//m; # Hashes can change but still be the same patch (patches before it in the inventory may affect its line numbers)
-        $diffable => { order => $order++, patch => $_ }
-    } $_[0]->patches;
+    map { $_->raw => { order => $order++, patch => $_ } } $_[0]->patches;
 }
 
 sub unhashify($) {
